@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -307,6 +307,9 @@ LibraryBrowser.initFileSystemTab = function() {
             var menu = LibraryBrowser.createItemContextMenu(dirTree, filePath, undefined, index);
             menu.exec(QCursor.pos());
         });
+
+    dirTree.installEventFilter(new REventFilter(QEvent.KeyPress.valueOf(), true));
+    dirTree.installEventFilter(new REventFilter(QEvent.KeyRelease.valueOf(), true));
 };
 
 LibraryBrowser.updateFileSystemTab = function() {
@@ -982,6 +985,8 @@ LibraryBrowser.directoryChanged = function(selected, deselected) {
     setOverrideWaitCursor();
     LibraryBrowser.updateFsView(dirPath, model);
     restoreOverrideCursor();
+
+    RSettings.setValue("LibraryBrowser/Path", dirPath);
 };
 
 /**
@@ -1966,19 +1971,21 @@ LibraryBrowser.showDirectory = function(dirName) {
     }
 
     var dirModel = dirTree.model();
-    var treeIndex = dirModel.pathIndex(dirName);
-    LibraryBrowser.deselectAllDirs();
-    var selectionModel = dirTree.selectionModel();
-    var flags = new QItemSelectionModel.SelectionFlags(QItemSelectionModel.Select);
-    var idxList = LibraryBrowser.getSelectedIndexes(selectionModel);
-    selectionModel.select(treeIndex, flags);
-    while (treeIndex.isValid()) {
-        dirTree.setExpanded(treeIndex, true);
-        treeIndex = treeIndex.parent();
-        QCoreApplication.processEvents();
+    if (!isNull(dirModel)) {
+        var treeIndex = dirModel.pathIndex(dirName);
+        LibraryBrowser.deselectAllDirs();
+        var selectionModel = dirTree.selectionModel();
+        var flags = new QItemSelectionModel.SelectionFlags(QItemSelectionModel.Select);
+        var idxList = LibraryBrowser.getSelectedIndexes(selectionModel);
+        selectionModel.select(treeIndex, flags);
+        while (treeIndex.isValid()) {
+            dirTree.setExpanded(treeIndex, true);
+            treeIndex = treeIndex.parent();
+            QCoreApplication.processEvents();
+        }
+        treeIndex = dirModel.pathIndex(dirName);
+        dirTree.scrollTo(treeIndex);
     }
-    treeIndex = dirModel.pathIndex(dirName);
-    dirTree.scrollTo(treeIndex);
     listView.scrollToTop();
 };
 
@@ -2019,5 +2026,8 @@ LibraryBrowser.showFirstTime = function() {
         }
         //LibraryBrowser.firstShow = false;
         appWin.setProperty("LibraryBrowser/FirstShow", true);
+
+        var initialPath = RSettings.getStringValue("LibraryBrowser/Path", "");
+        LibraryBrowser.showDirectory(initialPath);
     }
 };
